@@ -17,8 +17,14 @@ class Configuration(object):
 
   def __init__(self):
     self._files = []
+    self._debug = 0
     self._schemas = []
     self._aggregates = Aggregates()
+    self._transforms = {}
+
+  @property
+  def debug(self):
+    return self._debug
 
   def load(self, fname):
     '''
@@ -33,10 +39,17 @@ class Configuration(object):
     '''
     self._schemas = []
     self._aggregates = Aggregates()
+    self._transforms = {}
     
     for fname in self._files:
       self._load_source( fname )
 
+  def transform(self, name):
+    '''
+    Get a named transform from the configurations, or None if not found.
+    '''
+    return self._transforms.get(name)
+
   def schemas(self, stat):
     '''
     Get the matching schemas for a stat, or an empty list if there aren't any.
@@ -50,16 +63,25 @@ class Configuration(object):
     if not seen:
       seen = set()
     elif stat in seen:
-      return
+      return False
     seen.add(stat)
 
     aggregates = self._aggregates.match(stat)
     for schema in self._schemas:
-      schema.store(stat, val, timestamp)
+      stored = schema.store(stat, val, timestamp)
+      if self._debug:
+        if stored:
+          print 'STOR', stat, val, timestamp
+        elif self._debug > 1:
+          print 'SKIP', stat, val, timestamp
     
     # Infinite loop is prevented by match() implementation
     for ag in aggregates:
-      self.process(ag, val, timestamp, seen=seen)
+      processed = self.process(ag, val, timestamp, seen=seen)
+      if self._debug and processed:
+        print 'AGRT', ag, 'FROM', stat, val, timestamp
+
+    return True
 
   def load_schema(self, name, spec):
     self._schemas.append( Schema(name,spec) )
@@ -78,7 +100,13 @@ class Configuration(object):
 
       schemas = getattr(mod,'SCHEMAS',{})
       aggregates = getattr(mod,'AGGREGATES',[])
+      transforms = getattr(mod,'TRANSFORMS',{})
 
-      for name,schema in schemas.iteritems():
+      for name,schema in schemas.items():
         self.load_schema(name, schema)
       self.load_aggregate( aggregates )
+
+      for name,func in transforms.items():
+        self._transforms[name] = func
+      
+      self._debug = getattr(mod, 'DEBUG', self._debug)
